==> haskell-hjsmin-0.2.0.2-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsmin
version: 0.2.0.2
id: hjsmin-0.2.0.2-K3uG8BIsrjt26YWJOlhIMP
key: hjsmin-0.2.0.2-K3uG8BIsrjt26YWJOlhIMP
license: BSD3
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
stability: unstable
homepage: http://github.com/erikd/hjsmin
synopsis: Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.
category: Web
author: Alan Zimmerman <alan.zimm@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Jasmine
hidden-modules: Text.Jasmine.Pretty
abi: 96e5ec0d3b88cfbccfbd8e9b4978f24b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hjsmin-0.2.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hjsmin-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hjsmin-0.2.0.2
hs-libraries: HShjsmin-0.2.0.2-K3uG8BIsrjt26YWJOlhIMP
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz containers-0.5.10.2
    language-javascript-0.6.0.10-1S5Jj2C36PRBc01JV0pCfz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             language-javascript-0.6.0.10-1S5Jj2C36PRBc01JV0pCfz=33df8301fea6dba9bc90cf639cb0f009
haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html: /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.2.0.2-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsmin
version: 0.2.0.2
id: hjsmin-0.2.0.2-K8nVaREzpD7Hxnb4uVX4V
key: hjsmin-0.2.0.2-K8nVaREzpD7Hxnb4uVX4V
license: BSD3
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
stability: unstable
homepage: http://github.com/erikd/hjsmin
synopsis: Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.
category: Web
author: Alan Zimmerman <alan.zimm@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Jasmine
hidden-modules: Text.Jasmine.Pretty
abi: 26df19673530fe653ab3f0a035674274
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hjsmin-0.2.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hjsmin-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hjsmin-0.2.0.2
hs-libraries: HShjsmin-0.2.0.2-K8nVaREzpD7Hxnb4uVX4V
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz containers-0.5.10.2
    language-javascript-0.6.0.11-6yTrtHlze5G5jfn5hvfLcs
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             language-javascript-0.6.0.11-6yTrtHlze5G5jfn5hvfLcs=0079c859c26c612a35bdc60e19f5e7de
haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html: /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
